Index: app.c
===================================================================
RCS file: /usr/cvsroot/asterisk/app.c,v
retrieving revision 1.60
diff -u -u -r1.60 app.c
--- app.c	4 May 2005 15:26:03 -0000	1.60
+++ app.c	18 May 2005 21:42:04 -0000
@@ -1510,3 +1510,44 @@
 	return res;
 }
 
+/* rewrites data into buf with leading and trailing spaces trimmed off
+   ["] and ["] will be also considered
+   [    this is a test      ] -> 'this is a test'
+   [  " this is a test "    ] -> ' this is a test ' 
+*/
+
+int ast_trim_spaces(char *data, char *buf, size_t buflen)
+{
+	int len, q, ret = 0;
+	char *in, *p;
+
+	in = data;
+	len = strlen(in);
+
+	while (*in == ' ') {
+		in++;
+		ret++;
+	}
+	if (*in == '"') {
+		q = 1;
+		in++;
+	}
+
+	ast_copy_string(buf, in, buflen);
+	buflen = strlen(buf) -1;
+
+	for(p = buf + buflen; p != in ; p--) {
+		if (*p == ' ') {
+			*p = '\0';
+			ret++;
+		} else {
+			if (*p == '"') {
+				*p = '\0';
+				ret++;
+			}
+			break;
+		}
+	}
+
+	return ret;
+}
Index: include/asterisk/app.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/app.h,v
retrieving revision 1.35
diff -u -u -r1.35 app.h
--- include/asterisk/app.h	4 May 2005 03:43:10 -0000	1.35
+++ include/asterisk/app.h	18 May 2005 21:42:04 -0000
@@ -182,6 +182,9 @@
 /*! Allow to record message and have a review option */
 int ast_record_review(struct ast_channel *chan, const char *playfile, const char *recordfile, int maxtime, const char *fmt, int *duration, const char *path);
 
+/*! Remove spaces from a string (returns # of chars modified) */
+int ast_trim_spaces(char *data, char *buf, size_t buflen);
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
Index: funcs/func_logic.c
===================================================================
RCS file: /usr/cvsroot/asterisk/funcs/func_logic.c,v
retrieving revision 1.3
diff -u -u -r1.3 func_logic.c
--- funcs/func_logic.c	17 May 2005 16:45:42 -0000	1.3
+++ funcs/func_logic.c	18 May 2005 21:42:04 -0000
@@ -21,6 +21,7 @@
 #include "asterisk/app.h"
 #include "asterisk/config.h"		/* for ast_true */
 
+
 static char *builtin_function_isnull(struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len) 
 {
 	char *ret_true = "1", *ret_false = "0";
@@ -42,6 +43,7 @@
 	char *expr = NULL;
 	char *iftrue = NULL;
 	char *iffalse = NULL;
+	char *tbuf = NULL;
 
 	if((mydata = ast_strdupa(data))) {
 		expr = mydata;
@@ -55,6 +57,29 @@
 		} 
 
 		if (expr && iftrue) {
+			if ((tbuf = ast_strdupa(expr))) {
+				if((ast_trim_spaces(expr, tbuf, strlen(tbuf) + 1))) {
+					expr = tbuf;
+				} 
+			} else {
+				ast_log(LOG_WARNING, "Memory Error!\n");
+			}
+			if ((tbuf = ast_strdupa(iftrue))) {
+				if((ast_trim_spaces(iftrue, tbuf, strlen(tbuf) + 1))) {
+					iftrue = tbuf;
+				} 
+			} else {
+				ast_log(LOG_WARNING, "Memory Error!\n");
+			}
+			if (iffalse) {
+				if((tbuf = ast_strdupa(iffalse))) {
+					if (ast_trim_spaces(iffalse, tbuf, strlen(iffalse) + 1)) {
+						iffalse = tbuf;
+					}
+				} else {
+					ast_log(LOG_WARNING, "Memory Error!\n");
+				}
+			}
 			ret = ast_true(expr) ? iftrue : iffalse;
 			if (ret) {
 				ast_copy_string(buf, ret, len);
